##  World Map
The World Map Report of SAP LeanIX is a tool that provides an overview of which IT components and applications are used by user groups and their location on a world map. SAP LeanIX provides three default World Map reports: Application Sourcing report, the Application Usage report, and the IT Component Location report.
  1. The Application Usage report focuses on which applications are being used by which organizations/user groups. It allows users to identify which applications are popular and which are not being used as much, providing insight into how IT resources are being utilized by region. This report is region-specific, allowing users to zoom in on specific regions of interest. To use the Application Usage report, ensure location details are maintained in the Organization Fact Sheet and that it's connected to the relevant Application Fact Sheets.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747b4347a441014ab6adc2d7e66eff4_LowRes.png)
  2. The Application Sourcing report allows users to determine which IT components are being sourced from which region. It provides insight into the relationship between IT components and providers, allowing you to identify patterns and trends in IT assets sourcing by region. By zooming in on specific regions, users can get further details of the usage of applications within that region. To use the Application Sourcing report, ensure location details are maintained in the IT Component Fact Sheet and that relevant relations are established among relevant Application Fact Sheets and Provider Fact Sheets.
  3. The IT Component Location report shows which IT components are hosted or located in which countries or regions. It provides a visual representation of the distribution of your IT assets and is valuable for compliance-related scenarios where understanding and tracking who provides technology services and where they are hosted is essential. You can zoom in on specific regions to gain more detailed information. To use the IT Component Location report, ensure location details are maintained in the IT Component Fact Sheets.


In World Map Reports, you can visualize your data either by Country or Location for better understanding.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755a8017a441014b4f2f744ac560f79_LowRes.png)
Further, you can Zoom into a particular region by selecting a region from the Zoom drop-down menu. Alternatively, you can use the ‘+' / '-’ icons for zooming in and out.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750320e7a441014ad93b45a50b0a339_LowRes.png)
